part of masamune;

const double kPlatformThreshold = 768;

class PlatformBuilder extends StatelessWidget {
  const PlatformBuilder({
    this.mobile,
    this.desktop,
    this.thresholdWidth = kPlatformThreshold,
    this.defaultWidget = const Empty(),
  }) : assert(
          mobile != null || desktop != null,
          "You need to specify either [mobile] or [desktop].",
        );

  final double thresholdWidth;
  final Widget? mobile;
  final Widget? desktop;
  final Widget defaultWidget;

  @override
  Widget build(BuildContext context) {
    if (isMobile(context, thresholdWidth: kPlatformThreshold)) {
      return mobile ?? desktop ?? defaultWidget;
    } else {
      return desktop ?? mobile ?? defaultWidget;
    }
  }
}

class PlatformScrollbar extends StatelessWidget {
  const PlatformScrollbar({
    required this.child,
    this.thresholdWidth = kPlatformThreshold,
  });

  final Widget child;
  final double thresholdWidth;
  @override
  Widget build(BuildContext context) {
    if (isMobile(context, thresholdWidth: kPlatformThreshold)) {
      return child;
    } else {
      return Scrollbar(
        isAlwaysShown: true,
        child: child,
      );
    }
  }
}

bool isMobile(
  BuildContext context, {
  double thresholdWidth = kPlatformThreshold,
}) {
  if (Config.isAndroid || Config.isIOS) {
    return true;
  }
  final width = context.mediaQuery.size.width;
  if (width < thresholdWidth) {
    return true;
  }
  return false;
}
